==> haskell-sandi-0.5-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sandi
version: 0.5
id: sandi-0.5-KbEuVVsw1yKHTFm5wtl8aP
key: sandi-0.5-KbEuVVsw1yKHTFm5wtl8aP
license: BSD-3-Clause
maintainer: Magnus Therning <magnus@therning.org>
synopsis: Data encoding library
description:
    Reasonably fast data encoding library.
category: Codec, Conduit
abi: e1ab3012ca4df99cc3004885ef273e29
exposed: True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc
hidden-modules: Paths_sandi Data.Conduit.Codec.Util
import-dirs: /usr/lib/ghc-8.6.4/site-local/sandi-0.5
library-dirs: /usr/lib/ghc-8.6.4/site-local/sandi-0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/sandi-0.5
hs-libraries: HSsandi-0.5-KbEuVVsw1yKHTFm5wtl8aP
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-1rtgJXlCmiO4uvSrqLTkUm
    exceptions-0.10.1-7nkghZ77rTO8NZKanvk3XU
haddock-interfaces: /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html: /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sandi-0.5-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sandi
version: 0.5
id: sandi-0.5-98jxs4457uL9B2ngF8uadf
key: sandi-0.5-98jxs4457uL9B2ngF8uadf
license: BSD-3-Clause
maintainer: Magnus Therning <magnus@therning.org>
synopsis: Data encoding library
description:
    Reasonably fast data encoding library.
category: Codec, Conduit
abi: 9a9d4ea0712513b3a0ac8e3e33f9f37a
exposed: True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc
hidden-modules: Paths_sandi Data.Conduit.Codec.Util
import-dirs: /usr/lib/ghc-8.6.4/site-local/sandi-0.5
library-dirs: /usr/lib/ghc-8.6.4/site-local/sandi-0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/sandi-0.5
hs-libraries: HSsandi-0.5-98jxs4457uL9B2ngF8uadf
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-8MOrAYt7hu26dsIPZTK6mr
    exceptions-0.10.1-7EeRXpdm0c5D9yRsXefkxH
haddock-interfaces: /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html: /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
